======================
Zertrin Python Toolbox
======================


.. image:: https://img.shields.io/pypi/v/zkpytb.svg
        :target: https://pypi.python.org/pypi/zkpytb

.. image:: https://img.shields.io/travis/zertrin/zkpytb.svg
        :target: https://travis-ci.org/zertrin/zkpytb

.. image:: https://readthedocs.org/projects/zkpytb/badge/?version=latest
        :target: https://zkpytb.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/zertrin/zkpytb/shield.svg
     :target: https://pyup.io/repos/github/zertrin/zkpytb/
     :alt: Updates


A collection of useful functions by Zertrin


* Free software: MIT license
* Documentation: https://zkpytb.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

